@@ -331,14 +331,16 @@ class cmake_old(make):
         Run the tests in a Gaudi/LHCb project using CMT.
         '''
         kwargs['args'] = ['BUILDDIR=build'] + kwargs.get('args', [])
+        flags = ["--repeat until-pass:3"]
         if "jobs" in kwargs:
-            flag = "-j{}".format(kwargs.pop("jobs"))
-            for i, arg in enumerate(kwargs["args"]):
-                if arg.startswith("ARGS="):
-                    kwargs["args"][i] += " " + flag
-                    break
-            else:  # (this else matches the for) no ARGS= in args
-                kwargs["args"].append("ARGS={}".format(flag))
+            flags.append("-j{}".format(kwargs.pop("jobs")))
+
+        for i, arg in enumerate(kwargs["args"]):
+            if arg.startswith("ARGS="):
+                kwargs["args"][i] += " " + " ".join(flags)
+                break
+        else:  # (this else matches the for) no ARGS= in args
+            kwargs["args"].append("ARGS={}".format(" ".join(flags)))
 
         output = [
             self._make(target, proj, **kwargs)
@@ -576,7 +578,7 @@ class cmake_new(object):
             # no point trying to run the tests if we failed to configure
             return config_result
 
-        cmd = ['ctest', '-T', 'test']
+        cmd = ['ctest', '-T', 'test', '--repeat', 'until-pass:3']
         if 'jobs' in kwargs:
             cmd.extend(['-j', str(kwargs['jobs'])])
         test_result = self._call(
