@@ -234,7 +234,8 @@ def log_call(*args, **kwargs):
                 spilled_output[fd] = b''
                 for line in data.splitlines(True):
                     if line.endswith(b'\n'):
-                        log(log_level, line.decode().rstrip())
+                        log(log_level,
+                            line.decode('utf-8', errors='replace').rstrip())
                     else:
                         spilled_output[fd] += line
             else:
